@@ -15,7 +15,7 @@ CAMERA_KEYS = {
     "recording_mode_a",
     "recording_mode_c",
     "recording_mode_m",
-    "online",
+    "isOnline",
     "enabled",
     "reason",
     "lastMotion",
@@ -35,8 +35,10 @@ PROCESSED_EVENT_EMPTY = {
     "event_start": None,
     "event_on": False,
     "event_type": None,
+    "event_online": True,
     "event_length": 0,
     "event_object": [],
+    "event_score": 0,
 }
 
 REASON_CODES = {"128": "Human", "256": "Vehicle"}
@@ -72,6 +74,15 @@ def process_camera(server_id, server_credential, camera, include_events):
     image_width = str(camera["width"])
     image_height = str(camera["height"])
     latest_image = f"http://{base_url}/image?auth={server_credential['token']}&cameraNum={camera_id}&width={image_width}&height={image_height}&quality=75"
+    # PTZ
+    ptz_capabilities = camera.get("ptzcapabilities")
+    preset_list = []
+    if ptz_capabilities is not None and int(ptz_capabilities) > 0:
+        # Build a list of PTZ Presets
+        for preset in range(1, 10):
+            if camera.get(f"preset-name-{preset}") is not None:
+                preset_list.append(camera.get(f"preset-name-{preset}"))
+
     # Other Settings
     ip_address = "Local" if camera["devicetype"] == "Local" else camera.get("address")
 
@@ -91,6 +102,8 @@ def process_camera(server_id, server_credential, camera, include_events):
         "image_height": image_height,
         "fps": str(camera["current-fps"]),
         "video_format": str(camera["video-format"]),
+        "ptz_capabilities": ptz_capabilities,
+        "ptz_presets": preset_list,
     }
 
     if server_id is not None:
@@ -122,7 +135,6 @@ def camera_update_from_ws_frames(
         _LOGGER.debug("Skipping non-adopted camera: %s", data_json)
         return None, None
 
-    _LOGGER.debug("CAM UPDATE WS FRAME: %s", json.dumps(data_json))
     camera = state_machine.update(camera_id, data_json)
 
     if data_json.keys().isdisjoint(CAMERA_KEYS):
@@ -182,13 +194,14 @@ def event_from_ws_frames(state_machine, action_json, data_json):
 def camera_event_from_ws_frames(state_machine, action_json, data_json):
     """Create processed events from the camera model."""
 
-    if "isMotionDetected" not in data_json and "timesincelastmotion" not in data_json:
+    if "isMotionDetected" not in data_json and "timesincelastmotion" not in data_json and "isOnline" not in data_json:
         return None
 
     camera_id = action_json["id"]
     start_time = None
     event_length = 0
     event_on = False
+    is_online = data_json.get("isOnline")
 
     last_motion = int(time.time()) + int(data_json["timesincelastmotion"])
     is_motion_detected = data_json.get("isMotionDetected")
@@ -217,7 +230,7 @@ def camera_event_from_ws_frames(state_machine, action_json, data_json):
         "event_type": "motion",
         "event_start": start_time,
         "event_length": event_length,
-        "event_score": 0,
+        "event_online": is_online,
     }
 
 
@@ -227,6 +240,11 @@ def process_event(event):
     end = event.get("end")
     event_type = event.get("type")
     event_reason = event.get("reason")
+    event_online = event.get("isOnline")
+    if not event.get("event_score"):
+        event_score = 0
+    else:
+        event_score = event.get("event_score")
 
     event_length = 0
     start_time = None
@@ -248,6 +266,8 @@ def process_event(event):
         "event_start": start_time,
         "event_length": event_length,
         "event_object": event_object,
+        "event_score": event_score,
+        "event_online": event_online,
     }
 
     if event_type in (EVENT_MOTION, EVENT_SMART_DETECT_ZONE):
