@@ -85,6 +85,8 @@ class SecSpyServer:
         self._ws_subscriptions = []
         self._is_first_update = True
         self._signal_stop = False
+        self.global_event_score = 0
+        self.global_event_object = None
 
     @property
     def devices(self):
@@ -211,7 +213,6 @@ class SecSpyServer:
         image_height = height or DEFAULT_SNAPSHOT_HEIGHT
 
         image_uri = f"{self._base_url}/image?cameraNum={camera_id}&width={image_width}&height={image_height}&quality=75&auth={self._token}"
-        _LOGGER.debug(image_uri)
 
         response = await self.req.get(
             image_uri,
@@ -311,6 +312,22 @@ class SecSpyServer:
 
         return True
 
+    async def set_ptz_preset(self, camera_id: str, preset_id: str, speed: int=50) -> bool:
+        """Set a PTZ Preset."""
+        cam_uri = f"{self._base_url}/ptz/command?cameraNum={camera_id}&command={preset_id}&speed={speed}&auth={self._token}"
+
+        response = await self.req.get(
+            cam_uri,
+            headers=self.headers,
+            ssl=False,
+        )
+        if response.status != 200:
+            raise RequestError(
+                f"Setting PTZ Preset failed: {response.status} - Reason: {response.reason}"
+            )
+
+        return True
+
     async def enable_camera(self, camera_id: str, enabled: bool) -> bool:
         """Enables or disables the camera.
         Valid input for enabled is True or False
@@ -409,6 +426,7 @@ class SecSpyServer:
             return
         finally:
             _LOGGER.debug("stream disconnected")
+            await self.async_disconnect_ws()
             self.ws_connection = None
 
     def subscribe_websocket(self, ws_callback):
@@ -431,7 +449,6 @@ class SecSpyServer:
 
         action_array = msg.split(" ")
         action_key = action_array[3]
-        _LOGGER.debug("ACTION KEY: %s", action_key)
         model_key = None
         if action_key in CAMERA_MESSAGES:
             model_key = "camera"
@@ -473,27 +490,52 @@ class SecSpyServer:
                 data_json = {
                     "recordingSettings_M": False,
                 }
-            if action_key == "ONLINE":
-                data_json = {
-                    "online": True,
-                }
-            if action_key == "OFFLINE":
-                data_json = {
-                    "online": False,
-                }
+            # if action_key == "ONLINE":
+            #     data_json = {
+            #         "online": True,
+            #     }
+            # if action_key == "OFFLINE":
+            #     data_json = {
+            #         "online": False,
+            #     }
 
             self._process_camera_ws_message(action_json, data_json)
             return
 
         if model_key == "event":
+            if action_key == "ONLINE":
+                data_json = {
+                    "type": "online",
+                    "camera": action_array[2],
+                    "isOnline": True,
+                }
+                action_json = {
+                    "modelKey": "event",
+                    "action": "add",
+                    "id": action_array[2],
+                }
+            if action_key == "OFFLINE":
+                data_json = {
+                    "type": "online",
+                    "camera": action_array[2],
+                    "isOnline": False,
+                }
+                action_json = {
+                    "modelKey": "event",
+                    "action": "add",
+                    "id": action_array[2],
+                }
 
             if action_key == "TRIGGER_M":
+                self.global_event_object = action_array[4]
                 data_json = {
                     "type": "motion",
                     "start": action_array[0],
                     "camera": action_array[2],
-                    "reason": action_array[4],
+                    "reason": self.global_event_object,
+                    "event_score": self.global_event_score,
                     "isMotionDetected": True,
+                    "isOnline": True,
                 }
                 action_json = {
                     "modelKey": "event",
@@ -506,7 +548,10 @@ class SecSpyServer:
                     "type": "motion",
                     "start": action_array[0],
                     "camera": action_array[2],
+                    "reason": self.global_event_object,
+                    "event_score": self.global_event_score,
                     "isMotionDetected": True,
+                    "isOnline": True,
                 }
                 action_json = {
                     "modelKey": "event",
@@ -515,11 +560,14 @@ class SecSpyServer:
                 }
 
             if action_key == "MOTION_END":
+                self.global_event_score = 0
+                self.global_event_object = None
                 data_json = {
                     "type": "motion",
                     "end": action_array[0],
                     "camera": action_array[2],
                     "isMotionDetected": False,
+                    "isOnline": True,
                 }
                 action_json = {
                     "modelKey": "event",
@@ -529,21 +577,34 @@ class SecSpyServer:
 
             if action_key == "CLASSIFY":
                 # Can contain both HUMAN and VEHICLE
+                _LOGGER.debug("CLASSIFY: %s", action_array)
                 if len(action_array) > 6:
                     human_score = action_array[5]
                     vehicle_score = action_array[7]
-                    reason_code = "128" if human_score > vehicle_score else "256"
+                    if human_score > vehicle_score:
+                        self.global_event_object = "128"
+                        self.global_event_score = human_score
+                    else:
+                        self.global_event_object = "256"
+                        self.global_event_score = vehicle_score
                 else:
-                    reason_code = "128"
-                    if "HUMAN" not in action_array:
-                        reason_code = "256"
+                    if "HUMAN" or "VEHICLE" not in action_array:
+                        self.global_event_object = []
+                        self.global_event_score = 0
+                    else:
+                        self.global_event_object = "128"
+                        self.global_event_score = action_array[5]
+                        if "HUMAN" not in action_array:
+                            self.global_event_object = "256"
 
                 data_json = {
                     "type": "motion",
                     "start": action_array[0],
                     "camera": action_array[2],
-                    "reason": reason_code,
+                    "reason": self.global_event_object,
+                    "event_score": self.global_event_score,
                     "isMotionDetected": True,
+                    "isOnline": True,
                 }
                 action_json = {
                     "modelKey": "event",
@@ -567,7 +628,6 @@ class SecSpyServer:
 
         if camera_id is None:
             return
-        # _LOGGER.debug("Processed camera: %s", processed_camera)
 
         if not processed_camera["recording_mode_m"]:
             processed_event = camera_event_from_ws_frames(
@@ -602,7 +662,7 @@ class SecSpyServer:
         if device_id is None:
             return
 
-        # _LOGGER.debug("Procesed event: %s", processed_event)
+        _LOGGER.debug("Procesed event: %s", processed_event)
 
         self.fire_event(device_id, processed_event)
 
